@@ -1,22 +1,15 @@
+from typing import Union, Coroutine, Tuple
+from bilix.handle import Handler
 from bilix.log import logger
+from bilix.download.base_downloader import BaseDownloader
+from bilix.info.base_informer import BaseInformer
 
 
-class Handler:
-    registered = {}
-
-    def __init__(self, name):
-        self.name = name
-
-    def __call__(self, func):
-        self.registered[self.name] = func
-        return func
-
-
-def assign(**kwargs):
+def assign(**kwargs) -> Tuple[Union[BaseDownloader, BaseInformer], Coroutine]:
     bili_handler = Handler.registered.pop('bilibili')
     for name, handle in Handler.registered.items():
         if res := handle(**kwargs):
-            logger.info(f"Assign to {name}")
+            logger.debug(f"Assign to {name}")
             return res
     # since bilix is originally designed for bilibili, finally use bilibili handler
     return bili_handler(**kwargs)
